PacemakerSettings#

pydantic model autoplex.settings.PacemakerSettings[source]#

Model describing the hyperparameters for the Pacemaker (P-ACE) fits.

Structure matches the input.yaml sections of Pacemaker. Dictionary-based fields provide flexibility and allow any valid Pacemaker input. Note: If user provides a value for any nested dict field (e.g., ‘fit’, ‘potential’), it will COMPLETELY REPLACE the default value, not merge with it. Users should provide complete configurations for any field they customize.

field seed: int | None = 42#

Random seed

field metadata: dict[str, Any] | None = None#

Metadata dictionary

field cutoff: float | int | dict[str, Any] = 5.0#

Cutoff radius (float) or dict config (e.g. {name: hard, r_cut: 7.0})

field data: dict[str, Any] [Optional]#

Data configuration block. If provided by user, completely replaces default.

field potential: dict[str, Any] [Optional]#

Potential configuration block. If provided by user, completely replaces default.

field fit: dict[str, Any] [Optional]#

Fitting configuration block. If provided by user, completely replaces default.

field backend: dict[str, Any] [Optional]#

Backend execution settings. If provided by user, completely replaces default.