check_energy_force_stress_reading#
- autoplex.fitting.common.utils.check_energy_force_stress_reading(log_data)[source]#
Check if energies, forces, and stresses were read and parsed.
- Parameters:
log_data (str) – The MACE log file content as a string.
- Returns:
A dictionary with keys indicating whether energies, forces, and stresses were used (i.e., dataset summary counts > 0) for both Training and Validation: - “train_energy”: bool - “train_forces”: bool - “train_stress”: bool - “valid_energy”: bool - “valid_forces”: bool - “valid_stress”: bool
- Return type:
dict[str, bool]