autoplex.misc.utils.mock_custom_builder#
Simple example generator for amorphous structures.
Generates structures according to a formula and target density using a random hard sphere approach. Used for testing the CustomRandomizedStructure maker. Note that this script deliberately does NOT create any jobs or flows, as it is designed to mimic an external tool similar to buildcell.
Functions
Find a suitable position for a new atom. |
|
Calculate the lattice parameter for the simulation cell. |
|
Generate a unit cell and populate it at random. |