mock_generate_structure#
- autoplex.misc.utils.mock_custom_builder.mock_generate_structure()[source]#
Generate a unit cell and populate it at random.
Creates an empty unit cell atomic and then populates it with randomly positioned carbon atoms according to a target number of atoms (population) and the target average density.
Notes
The function will calculate the required cell size based on this and the sum of the atomic masses, using calculate_cell_size